@@ -13,28 +13,39 @@
 
 # Third-party imports
 from mxnet import nd
+import pytest
 
 # First-party imports
 from gluonts.mx.block.quantile_output import QuantileLoss
 
 
-def test_compute_quantile_loss() -> None:
+@pytest.mark.parametrize(
+    "quantile_weights, correct_qt_loss",
+    [
+        (None, [1.0, 1.8]),
+        ([0.5, 0.5], 1.4),
+    ],
+)
+def test_compute_quantile_loss(quantile_weights, correct_qt_loss) -> None:
     y_true = nd.ones(shape=(10, 10, 10))
     y_pred = nd.zeros(shape=(10, 10, 10, 2))
 
     quantiles = [0.5, 0.9]
 
-    loss = QuantileLoss(quantiles)
-
-    correct_qt_loss = [1.0, 1.8]
-
-    for idx, q in enumerate(quantiles):
-        assert (
-            nd.mean(
-                loss.compute_quantile_loss(
-                    nd.ndarray, y_true, y_pred[:, :, :, idx], q
+    loss = QuantileLoss(quantiles, quantile_weights)
+    tol = 1e-5
+    if not quantile_weights:
+        for idx, q in enumerate(quantiles):
+            assert (
+                nd.mean(
+                    loss.compute_quantile_loss(
+                        nd.ndarray, y_true, y_pred[:, :, :, idx], q
+                    )
                 )
-            )
-            - correct_qt_loss[idx]
-            < 1e-5
-        ), f"computing quantile loss at quantile {q} fails!"
+                - correct_qt_loss[idx]
+                < tol
+            ), f"computing quantile loss at quantile {q} fails!"
+    else:
+        assert (
+            nd.mean(loss(y_true, y_pred)) - correct_qt_loss < tol
+        ), f"computing weighted quantile loss fails!"
